@@ -9,8 +9,9 @@ use warnings;
 
 use CGI ();
 use File::Spec;
+use Scalar::Util 'blessed';
 
-use version 0.77; our $VERSION = qv("v0.5.1");
+use version 0.77; our $VERSION = qv("v0.5.2");
 
 my %TemplateCache;
 
@@ -84,9 +85,9 @@ sub parse {
 
     my $error = sub {
         my ($message, $errorPos) = @_;
-        my @lineCount = split("\n", substr($tmpl, 0, $errorPos));
+        my $lineCount = substr($tmpl, 0, $errorPos) =~ tr/\n/\n/;
 
-        die $message . "\nLine " . length(@lineCount);
+        die $message . "\nLine " . $lineCount
     };
 
     # Build the pattern, and instruct the regex engine to begin at `$start`.
@@ -275,8 +276,9 @@ sub lookup {
             next unless exists $ctx->{$field};
             $value = $ctx->{$field};
             last;
-        } else {
-            next unless UNIVERSAL::can($ctx, $field);
+        } elsif ($ctx && (blessed($ctx) || ! ref $ctx) && $ctx->can($field)) {;
+            # We want to accept class names and objects, but not unblessed refs
+            # or undef. -- rjbs, 2015-06-12
             $value = $ctx->$field();
             last;
         }
